.. ecspy documentation master file, created by
   sphinx-quickstart on Tue Jul 07 00:35:34 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ecspy's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2
   
   ec_intro
   swarm_intro
   tutorial
   examples
   reference

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

